@@ -328,6 +328,71 @@ class Wsdl(WsdlBase):
                                             'cl_dispatch_conf'),
                                     next_label=_("Run"))],
         },
+        {
+            # идентификатор метода
+            'method_name': Builder.Method.Container,
+            # категория метода
+            'category': __('Builder'),
+            # заголовок метода
+            'title': __("Create the Container"),
+            # иконка для графической консоли
+            'image': 'calculate-builder-image,media-optical,media-optical-data',
+            # метод присутствует в графической консоли
+            'gui': True,
+            # консольная команда
+            'command': 'cl-builder-container',
+            # права для запуска метода
+            'rights': ['build'],
+            # объект содержащий модули для действия
+            'logic': {'Builder': Builder,
+                      'Install': Install},
+            # описание действия
+            'action': ClBuilderImageAction,
+            # объект переменных
+            'datavars': "builder",
+            'native_error': (VariableError, DataVarsError, EmergeError,
+                             InstallError, BuilderError, GitError),
+            # значения по умолчанию для переменных этого метода
+            'setvars': {'cl_action!': BuilderActions.Image,
+                        'cl_builder_image_type': 'container',
+                        'cl_dispatch_conf_default': 'usenew'},
+            # описание груп (список лямбда функций)
+            'groups': [
+                lambda group: group(_("Create the Container"),
+                                    normal=('cl_builder_prepared_id',
+                                            'cl_builder_image_filename',
+                                            ),
+                                    brief=('cl_builder_prepared_id',
+                                           'os_builder_linux_fullname',
+                                           'os_builder_linux_shortname',
+                                           'os_builder_linux_subname',
+                                           'os_builder_linux_system',
+                                           'os_builder_linux_ver',
+                                           'os_builder_linux_build',
+                                           'cl_builder_image_filename',
+                                           'cl_builder_keep_tree_set',
+                                           'cl_builder_prelink_set',
+                                           'cl_builder_container_free_size'
+                                           ),
+                                    hide=('cl_templates_locate',
+                                          'cl_verbose_set',
+                                          'cl_dispatch_conf'
+                                          'cl_builder_prepared_id',
+                                          'cl_builder_image_filename',
+                                          'cl_builder_keep_tree_set',
+                                          'cl_builder_prelink_set',
+                                          ),
+                                    expert=(
+                                        'cl_builder_keep_tree_set',
+                                        'cl_builder_prelink_set',
+                                        'cl_builder_binhost_stable_set',
+                                        'cl_templates_locate',
+                                        'cl_verbose_set',
+                                        'cl_dispatch_conf'),
+                                    next_label=_("Next"))],
+            'brief': {'next': __("Run"),
+                      'name': __("Create the Container")}
+        },
         {
             # идентификатор метода
             'method_name': Builder.Method.Image,
@@ -354,6 +419,7 @@ class Wsdl(WsdlBase):
                              InstallError, BuilderError, GitError),
             # значения по умолчанию для переменных этого метода
             'setvars': {'cl_action!': BuilderActions.Image,
+                        'cl_builder_image_type': 'iso',
                         'cl_dispatch_conf_default': 'usenew'},
             # описание груп (список лямбда функций)
             'groups': [
